@@ -112,22 +112,25 @@ def test_writer(app, status, warning):
     app.builder.build_all()
     result = (app.outdir / 'SphinxTests.tex').text(encoding='utf8')
 
-    assert ('\\begin{figure-in-table}\n\\centering\n\\capstart\n'
-            '\\includegraphics{{img}.png}\n'
-            '\\figcaption{figure in table}\\label{markup:id7}\\end{figure-in-table}' in result)
+    assert ('\\begin{sphinxfigure-in-table}\n\\centering\n\\capstart\n'
+            '\\noindent\\sphinxincludegraphics{{img}.png}\n'
+            '\\sphinxfigcaption{figure in table}\\label{markup:id7}'
+            '\\end{sphinxfigure-in-table}\\relax' in result)
 
     assert ('\\begin{wrapfigure}{r}{0pt}\n\\centering\n'
-            '\\includegraphics{{rimg}.png}\n\\caption{figure with align option}'
-            '\\label{markup:id8}\\end{wrapfigure}' in result)
+            '\\noindent\\sphinxincludegraphics{{rimg}.png}\n'
+            '\\caption{figure with align option}\\label{markup:id8}'
+            '\\end{wrapfigure}' in result)
 
     assert ('\\begin{wrapfigure}{r}{0.500\\linewidth}\n\\centering\n'
-            '\\includegraphics{{rimg}.png}\n\\caption{figure with align \\& figwidth option}'
-            '\\label{markup:id9}\\end{wrapfigure}' in result)
+            '\\noindent\\sphinxincludegraphics{{rimg}.png}\n'
+            '\\caption{figure with align \\& figwidth option}\\label{markup:id9}'
+            '\\end{wrapfigure}' in result)
 
     assert ('\\begin{wrapfigure}{r}{3cm}\n\\centering\n'
-            '\\includegraphics[width=3cm]{{rimg}.png}\n'
-            '\\caption{figure with align \\& width option}'
-            '\\label{markup:id10}\\end{wrapfigure}' in result)
+            '\\noindent\\sphinxincludegraphics[width=3cm]{{rimg}.png}\n'
+            '\\caption{figure with align \\& width option}\\label{markup:id10}'
+            '\\end{wrapfigure}' in result)
 
 
 @with_app(buildername='latex', freshenv=True,  # use freshenv to check warnings
@@ -409,7 +412,7 @@ def test_footnote(app, status, warning):
     assert '\\footnote[1]{\sphinxAtStartFootnote%\nnumbered\n}' in result
     assert '\\footnote[2]{\sphinxAtStartFootnote%\nauto numbered\n}' in result
     assert '\\footnote[3]{\sphinxAtStartFootnote%\nnamed\n}' in result
-    assert '{\\hyperref[footnote:bar]{\\crossref{{[}bar{]}}}}' in result
+    assert '{\\hyperref[footnote:bar]{\\sphinxcrossref{{[}bar{]}}}}' in result
     assert '\\bibitem[bar]{bar}{\\phantomsection\\label{footnote:bar} ' in result
     assert '\\bibitem[bar]{bar}{\\phantomsection\\label{footnote:bar} \ncite' in result
     assert '\\bibitem[bar]{bar}{\\phantomsection\\label{footnote:bar} \ncite\n}' in result
@@ -428,7 +431,7 @@ def test_reference_in_caption(app, status, warning):
     print(status.getvalue())
     print(warning.getvalue())
     assert ('\\caption{This is the figure caption with a reference to \\label{index:id2}'
-            '{\\hyperref[index:authoryear]{\\crossref{{[}AuthorYear{]}}}}.}' in result)
+            '{\\hyperref[index:authoryear]{\\sphinxcrossref{{[}AuthorYear{]}}}}.}' in result)
     assert '\\chapter{The section with a reference to {[}AuthorYear{]}}' in result
     assert '\\caption{The table title with a reference to {[}AuthorYear{]}}' in result
     assert '\\paragraph{The rubric title with a reference to {[}AuthorYear{]}}' in result
@@ -462,11 +465,12 @@ def test_latex_show_urls_is_inline(app, status, warning):
             'footnote in baz\n} in baz.rst' in result)
     assert ('\\phantomsection\\label{index:id26}{\\hyperref[index:the\\string-section'
             '\\string-with\\string-a\\string-reference\\string-to\\string-authoryear]'
-            '{\\crossref{The section with a reference to \\phantomsection\\label{index:id1}'
-            '{\\hyperref[index:authoryear]{\\crossref{{[}AuthorYear{]}}}}}}}' in result)
+            '{\\sphinxcrossref{The section with a reference to '
+            '\\phantomsection\\label{index:id1}'
+            '{\\hyperref[index:authoryear]{\\sphinxcrossref{{[}AuthorYear{]}}}}}}}' in result)
     assert ('\\phantomsection\\label{index:id27}{\\hyperref[index:the\\string-section'
             '\\string-with\\string-a\\string-reference\\string-to]'
-            '{\\crossref{The section with a reference to }}}' in result)
+            '{\\sphinxcrossref{The section with a reference to }}}' in result)
     assert 'First footnote: \\footnote[2]{\sphinxAtStartFootnote%\nFirst\n}' in result
     assert 'Second footnote: \\footnote[1]{\sphinxAtStartFootnote%\nSecond\n}' in result
     assert '\\href{http://sphinx-doc.org/}{Sphinx} (http://sphinx-doc.org/)' in result
@@ -499,11 +503,12 @@ def test_latex_show_urls_is_footnote(app, status, warning):
             'footnote in baz\n} in baz.rst' in result)
     assert ('\\phantomsection\\label{index:id26}{\\hyperref[index:the\\string-section'
             '\\string-with\\string-a\\string-reference\\string-to\\string-authoryear]'
-            '{\\crossref{The section with a reference to \\phantomsection\\label{index:id1}'
-            '{\\hyperref[index:authoryear]{\\crossref{{[}AuthorYear{]}}}}}}}' in result)
+            '{\\sphinxcrossref{The section with a reference '
+            'to \\phantomsection\\label{index:id1}'
+            '{\\hyperref[index:authoryear]{\\sphinxcrossref{{[}AuthorYear{]}}}}}}}' in result)
     assert ('\\phantomsection\\label{index:id27}{\\hyperref[index:the\\string-section'
             '\\string-with\\string-a\\string-reference\\string-to]'
-            '{\\crossref{The section with a reference to }}}' in result)
+            '{\\sphinxcrossref{The section with a reference to }}}' in result)
     assert 'First footnote: \\footnote[3]{\sphinxAtStartFootnote%\nFirst\n}' in result
     assert 'Second footnote: \\footnote[1]{\sphinxAtStartFootnote%\nSecond\n}' in result
     assert ('\\href{http://sphinx-doc.org/}{Sphinx}'
@@ -542,11 +547,12 @@ def test_latex_show_urls_is_no(app, status, warning):
             'footnote in baz\n} in baz.rst' in result)
     assert ('\\phantomsection\\label{index:id26}{\\hyperref[index:the\\string-section'
             '\\string-with\\string-a\\string-reference\\string-to\\string-authoryear]'
-            '{\\crossref{The section with a reference to \\phantomsection\\label{index:id1}'
-            '{\\hyperref[index:authoryear]{\\crossref{{[}AuthorYear{]}}}}}}}' in result)
+            '{\\sphinxcrossref{The section with a reference '
+            'to \\phantomsection\\label{index:id1}'
+            '{\\hyperref[index:authoryear]{\\sphinxcrossref{{[}AuthorYear{]}}}}}}}' in result)
     assert ('\\phantomsection\\label{index:id27}{\\hyperref[index:the\\string-section'
             '\\string-with\\string-a\\string-reference\\string-to]'
-            '{\\crossref{The section with a reference to }}}' in result)
+            '{\\sphinxcrossref{The section with a reference to }}}' in result)
     assert 'First footnote: \\footnote[2]{\sphinxAtStartFootnote%\nFirst\n}' in result
     assert 'Second footnote: \\footnote[1]{\sphinxAtStartFootnote%\nSecond\n}' in result
     assert '\\href{http://sphinx-doc.org/}{Sphinx}' in result
@@ -571,12 +577,13 @@ def test_image_in_section(app, status, warning):
     print(result)
     print(status.getvalue())
     print(warning.getvalue())
-    assert ('\chapter[Test section]'
-            '{\includegraphics[width=15pt,height=15pt]{{pic}.png} Test section}'
+    assert ('\\chapter[Test section]{\\lowercase{\\sphinxincludegraphics'
+            '[width=15pt,height=15pt]}{{pic}.png} Test section}'
             in result)
-    assert ('\chapter[Other {[}blah{]} section]{Other {[}blah{]} '
-            '\includegraphics[width=15pt,height=15pt]{{pic}.png} section}' in result)
-    assert ('\chapter{Another section}' in result)
+    assert ('\\chapter[Other {[}blah{]} section]{Other {[}blah{]} '
+            '\\lowercase{\\sphinxincludegraphics[width=15pt,height=15pt]}'
+            '{{pic}.png} section}' in result)
+    assert ('\\chapter{Another section}' in result)
 
 
 @with_app(buildername='latex', confoverrides={'latex_logo': 'notfound.jpg'})
